make_csc_symm_matrix: Convert a plain matrix or simple triplet form matrix to a...

View source: R/sparse.R

make_csc_symm_matrixR Documentation

Convert a plain matrix or simple triplet form matrix to a Matrix::dsCMatrix (implicit, upper) form

Description

Convert a plain matrix or simple triplet form matrix to a Matrix::dsCMatrix (implicit, upper) form

Usage

make_csc_symm_matrix(m)

Arguments

m

a matrix or a simple triplet form matrix

Value

a list of row pointer, column pointer, and values corresponding to a Matrix::dsCMatrix object


piqp documentation built on Oct. 6, 2026, 9:07 a.m.