| make_csc_symm_matrix | R Documentation |
Convert a plain matrix or simple triplet form matrix to a Matrix::dsCMatrix (implicit, upper) form
make_csc_symm_matrix(m)
m |
a matrix or a simple triplet form matrix |
a list of row pointer, column pointer, and values corresponding to a Matrix::dsCMatrix object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.