An S7 class wrapping the PIQP C++ Solver. Users will never
need to directly create instances of this class and should use the
more user-friendly functions piqp() and solve_piqp().
piqp_model(solver_ptr = NULL, dims = list(), dense_backend = logical(0))external pointer to the C++ solver object
a named list with elements n, p, and m
logical flag indicating if the dense solver is used